@@ -50,9 +50,7 @@
 package com.openexchange.publish.microformats;
 
 import java.io.IOException;
-import java.io.StringWriter;
 import java.io.UnsupportedEncodingException;
-import java.nio.charset.Charset;
 import java.text.DateFormat;
 import java.text.SimpleDateFormat;
 import java.util.ArrayList;
@@ -62,13 +60,9 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.TimeZone;
-
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
-
 import org.apache.commons.logging.Log;
-import com.openexchange.log.LogFactory;
-
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.contact.ContactService;
 import com.openexchange.exception.OXException;
@@ -76,7 +70,9 @@ import com.openexchange.groupware.container.Contact;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.html.HtmlService;
+import com.openexchange.java.AllocatingStringWriter;
 import com.openexchange.java.Strings;
+import com.openexchange.log.LogFactory;
 import com.openexchange.publish.Publication;
 import com.openexchange.publish.PublicationDataLoaderService;
 import com.openexchange.publish.microformats.osgi.StringTranslator;
@@ -129,7 +125,6 @@ public class MicroformatServlet extends OnlinePublicationServlet {
 
     private static final DateFormat TIME_FORMAT = new SimpleDateFormat("yyyy-MM-dd H:m:s.S z");
 
-
     static {
         TIME_FORMAT.setTimeZone(TimeZone.getTimeZone("UTC"));
     }
@@ -142,7 +137,6 @@ public class MicroformatServlet extends OnlinePublicationServlet {
         dataLoader = service;
     }
 
-
     public static void setUserService(final UserService service) {
         userService = service;
     }
@@ -168,7 +162,6 @@ public class MicroformatServlet extends OnlinePublicationServlet {
         htmlService = htmlService2;
     }
 
-
     @Override
     protected void service(final HttpServletRequest req, final HttpServletResponse resp) throws IOException {
         try {
@@ -197,7 +190,6 @@ public class MicroformatServlet extends OnlinePublicationServlet {
                 return;
             }
 
-
             final Collection<? extends Object> loaded = dataLoader.load(publication);
 
             final HashMap<String, Object> variables = new HashMap<String, Object>();
@@ -210,15 +202,11 @@ public class MicroformatServlet extends OnlinePublicationServlet {
             variables.put("dateFormat", DATE_FORMAT);
             variables.put("timeFormat", TIME_FORMAT);
             String admin = configService.getProperty("PUBLISH_REVOKE");
-            if(admin == null || admin.equals("")) {
+            if (admin == null || admin.equals("")) {
                 admin = userService.getUser(ctx.getMailadmin(), ctx).getMail();
             }
-            final String privacyText = formatPrivacyText(
-                getPrivacyText(user),
-                admin,
-                user,
-                new Date());
-            variables.put("privacy", privacyText ); //TODO Use lastmodified once someone implements this.
+            final String privacyText = formatPrivacyText(getPrivacyText(user), admin, user, new Date());
+            variables.put("privacy", privacyText); // TODO Use lastmodified once someone implements this.
             variables.put("userContact", userContact);
             variables.put("htmlService", new HTMLUtils(htmlService));
 
@@ -227,18 +215,18 @@ public class MicroformatServlet extends OnlinePublicationServlet {
             }
 
             final OXTemplate template = publisher.loadTemplate(publication);
-            final StringWriter htmlWriter = new StringWriter();
+            final AllocatingStringWriter htmlWriter = new AllocatingStringWriter();
             template.process(variables, htmlWriter);
             String html = htmlWriter.toString();
-            if(isUsingWhitelisting(template.getLevel())){
-            	html = htmlService.getConformHTML(html, Charset.defaultCharset().toString());
-            	html = htmlService.filterWhitelist(html, "microformatWhitelist");
+            if (isUsingWhitelisting(template.getLevel())) {
+                //html = htmlService.getConformHTML(html, Charset.defaultCharset().toString());
+                html = htmlService.sanitize(html, "microformatWhitelist", false, null, null);
             }
             resp.getWriter().write(html);
 
         } catch (final OXException x) {
             LOG.error(x.getMessage(), x);
-            resp.getWriter().println("Publishing failed. Please try again later. Exception ID: "+x.getExceptionId());
+            resp.getWriter().println("Publishing failed. Please try again later. Exception ID: " + x.getExceptionId());
 
         } catch (final Throwable t) {
             LOG.error(t.getMessage(), t);
@@ -247,31 +235,29 @@ public class MicroformatServlet extends OnlinePublicationServlet {
     }
 
     private boolean isUsingWhitelisting(final TemplateLevel templateLevel) {
-    	final String globalWhitelisting = configService.getProperty(USE_WHITELISTING_PROPERTY_NAME, "false");
+        final String globalWhitelisting = configService.getProperty(USE_WHITELISTING_PROPERTY_NAME, "false");
 
-    	if (Boolean.parseBoolean(globalWhitelisting)) {
-    	    return true;
-    	}
+        if (Boolean.parseBoolean(globalWhitelisting)) {
+            return true;
+        }
 
-    	final String[] strings = globalWhitelisting.split("\\s*,\\s*");
-    	for (final String string : strings) {
+        for (final String string : Strings.splitByComma(globalWhitelisting)) {
             if (templateLevel.name().toLowerCase().equals(string.toLowerCase())) {
                 return true;
             }
         }
 
-    	return false;
-	}
-
-	private Contact getContact(final PublicationSession publicationSession, final Context context) throws OXException {
-        return contacts.getUser(publicationSession, publicationSession.getUserId()); 
+        return false;
     }
 
+    private Contact getContact(final PublicationSession publicationSession, final Context context) throws OXException {
+        return contacts.getUser(publicationSession, publicationSession.getUserId());
+    }
 
     private String formatPrivacyText(final String privacyText, final String adminAddress, final User user, final Date creationDate) {
         final String date = new SimpleDateFormat("yyyy-MM-dd").format(creationDate);
         final String retVal = String.format(privacyText, adminAddress, user.getMail(), date);
-        return "<p>" +retVal.replaceAll("\n", "</p><p>") + "</p>";
+        return "<p>" + retVal.replaceAll("\n", "</p><p>") + "</p>";
     }
 
     private String getCollectionName(final String module) {
@@ -303,7 +289,7 @@ public class MicroformatServlet extends OnlinePublicationServlet {
         return user;
     }
 
-    private String getPrivacyText(final User user){
+    private String getPrivacyText(final User user) {
         return translator.translate(user.getLocale(), MicroformatStrings.DISCLAIMER_PRIVACY);
     }
 
