@@ -179,11 +179,16 @@ public class OXMFPublicationService extends AbstractPublicationService {
             return templateService.loadTemplate(defaultTemplateName);
         }
         final String templateName = object.toString();
-        if (templateName == null || "".equals(templateName)) {
-            return templateService.loadTemplate(defaultTemplateName);
+        try {
+            if (templateName == null || "".equals(templateName)) {
+                return templateService.loadTemplate(defaultTemplateName);
+            }
+            final ServerSession serverSession = ServerSessionAdapter.valueOf(new PublicationSession(publication));
+            return templateService.loadTemplate(templateName, defaultTemplateName, serverSession);
+        } catch (final OXException e) {
+            throw e;
         }
-        final ServerSession serverSession = ServerSessionAdapter.valueOf(new PublicationSession(publication));
-        return templateService.loadTemplate(templateName, defaultTemplateName, serverSession);
+
     }
 
     @Override
